==> zent-9.12.16.tgz: package/es/i18n/zh-CN.js <==
import { __assign } from "tslib";
import { Fragment as _Fragment, jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { setLocale, zhCN } from './time-locale';
var common = {
    confirm: '确定',
    cancel: '取消',
    ok: '我知道了',
    comma: '，',
    reset: '重置',
};
export var mark = 'zh-CN';
export var CopyButton = {
    copy: '复制',
    success: '复制成功',
    error: '复制失败',
};
export var Pagination = {
    jumpTo: function (_a) {
        var input = _a.input;
        return _jsxs(_Fragment, { children: ["\u8DF3\u81F3", input, "\u9875"] }, void 0);
    },
    pageStats: function (_a) {
        var total = _a.total, select = _a.select, Text = _a.Text;
        return (_jsxs(_Fragment, { children: ["\u5171 ", _jsx(Text, __assign({ type: "middle" }, { children: total }), void 0), " \u6761\uFF0C\u6BCF\u9875", select] }, void 0));
    },
    pageStatsStatic: function (_a) {
        var total = _a.total, pageSize = _a.pageSize, Text = _a.Text;
        return (_jsxs(_Fragment, { children: ["\u5171 ", _jsx(Text, __assign({ type: "middle" }, { children: total }), void 0), " \u6761\uFF0C\u6BCF\u9875", _jsx(Text, __assign({ type: "middle" }, { children: pageSize }), void 0), " \u6761"] }, void 0));
    },
    selectWidth: 80,
    items: '条',
};
export var Pop = __assign({}, common);
export var PreviewImage = {
    alt: '图片下载失败',
    prev: '上一张',
    next: '下一张',
    rotate: '翻转',
};
export var RangePicker = {
    7: '近7天',
    30: '近30天',
};
export var Select = {
    input: '请选择',
    empty: '无搜索结果',
    tagSeparator: '、',
    create: '+点击新建：',
};
export var Switch = {
    checked: '开启',
    unchecked: '关闭',
};
export var Sweetalert = __assign(__assign({}, common), { title: '提示' });
export var Grid = __assign(__assign({}, common), { emptyLabel: '没有更多数据了' });
export var Cascader = __assign(__assign({}, common), { title: '标题', placeholder: '请选择', searchPlaceholder: '请选择或输入搜索', searchEmpty: '无搜索结果', empty: '无数据' });
var QUARTER_NAMES = ['第一季度', '第二季度', '第三季度', '第四季度'];
export var TimePicker = function () {
    setLocale(zhCN);
    return __assign(__assign({}, common), { time: '请选择时间', date: '请选择日期', week: '请选择自然周', month: '请选择月份', quarter: '请选择季度', year: '请选择年份', range: '开始日期 至 结束日期', timeErrorPop: '时间不可用', dateErrorPop: '日期不可用', start: '开始日期', end: '结束日期', startTime: '开始时间', endTime: '结束时间', to: '至', current: {
            time: '当前时间',
            date: '今天',
            week: '当前周',
            month: '当前月',
            year: '当前年',
        }, panel: {
            hour: '时',
            minute: '分',
            second: '秒',
            year: '年',
            hourSelect: '选择小时',
            minuteSelect: '选择分钟',
            secondSelect: '选择秒',
            titleFormat: 'YYYY年MMM',
            quarterNames: QUARTER_NAMES,
            yearQuarterName: function (_a) {
                var year = _a.year, quarter = _a.quarter;
                var val = QUARTER_NAMES[quarter];
                return year + "\u5E74" + val;
            },
            dayNames: ['日', '一', '二', '三', '四', '五', '六'],
            monthNames: [
                '1月',
                '2月',
                '3月',
                '4月',
                '5月',
                '6月',
                '7月',
                '8月',
                '9月',
                '10月',
                '11月',
                '12月',
            ],
        } });
};
export var Upload = __assign(__assign({}, common), { delete: '删除', retry: '重新上传', failed: '上传失败', limit: '文件添加个数已达上限', add: '添加文件', uploading: '文件上传中' });
export var Mention = {
    noContent: '无匹配结果，轻敲空格完成输入',
};
export var Transfer = {
    placeholder: '请输入搜索内容',
    item: '项',
    items: '项',
    emptyLabel: '暂无数据',
};
export var Form = {
    required: '必填',
};

==> zent-10.0.15.tgz: package/es/i18n/zh-CN.js <==
import { __assign } from "tslib";
import { Fragment as _Fragment, jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { setLocale, zhCN } from './time-locale';
var common = {
    confirm: '确定',
    cancel: '取消',
    ok: '我知道了',
    comma: '，',
    reset: '重置',
};
export var mark = 'zh-CN';
export var CopyButton = {
    copy: '复制',
    success: '复制成功',
    error: '复制失败',
};
export var Pagination = {
    jumpTo: function (_a) {
        var input = _a.input;
        return _jsxs(_Fragment, { children: ["\u8DF3\u81F3", input, "\u9875"] }, void 0);
    },
    pageStats: function (_a) {
        var total = _a.total, select = _a.select, Text = _a.Text;
        return (_jsxs(_Fragment, { children: ["\u5171 ", _jsx(Text, __assign({ type: "middle" }, { children: total }), void 0), " \u6761\uFF0C\u6BCF\u9875", select] }, void 0));
    },
    pageStatsStatic: function (_a) {
        var total = _a.total, pageSize = _a.pageSize, Text = _a.Text;
        return (_jsxs(_Fragment, { children: ["\u5171 ", _jsx(Text, __assign({ type: "middle" }, { children: total }), void 0), " \u6761\uFF0C\u6BCF\u9875", _jsx(Text, __assign({ type: "middle" }, { children: pageSize }), void 0), " \u6761"] }, void 0));
    },
    selectWidth: 80,
    items: '条',
};
export var Pop = __assign({}, common);
export var PreviewImage = {
    alt: '图片下载失败',
    prev: '上一张',
    next: '下一张',
    rotate: '翻转',
};
export var RangePicker = {
    7: '近7天',
    30: '近30天',
};
export var Select = {
    input: '请选择',
    empty: '暂无数据',
    tagSeparator: '、',
    create: '+点击新建：',
};
export var Switch = {
    checked: '开启',
    unchecked: '关闭',
};
export var Sweetalert = __assign(__assign({}, common), { title: '提示' });
export var Grid = __assign(__assign({}, common), { emptyLabel: '没有更多数据了' });
export var Cascader = __assign(__assign({}, common), { title: '标题', placeholder: '请选择', searchPlaceholder: '请选择或输入搜索', searchEmpty: '无搜索结果', empty: '无数据', loading: '加载中…' });
var QUARTER_NAMES = ['第一季度', '第二季度', '第三季度', '第四季度'];
export var TimePicker = function () {
    setLocale(zhCN);
    return __assign(__assign({}, common), { time: '请选择时间', date: '请选择日期', week: '请选择自然周', month: '请选择月份', quarter: '请选择季度', year: '请选择年份', range: '开始日期 至 结束日期', timeErrorPop: '时间不可用', dateErrorPop: '日期不可用', start: '开始日期', end: '结束日期', startTime: '开始时间', endTime: '结束时间', to: '至', current: {
            time: '当前时间',
            date: '今天',
            week: '当前周',
            month: '当前月',
            year: '当前年',
        }, panel: {
            hour: '时',
            minute: '分',
            second: '秒',
            year: '年',
            hourSelect: '选择小时',
            minuteSelect: '选择分钟',
            secondSelect: '选择秒',
            titleFormat: 'YYYY年MMM',
            quarterNames: QUARTER_NAMES,
            yearQuarterName: function (_a) {
                var year = _a.year, quarter = _a.quarter;
                var val = QUARTER_NAMES[quarter];
                return year + "\u5E74" + val;
            },
            dayNames: ['日', '一', '二', '三', '四', '五', '六'],
            monthNames: [
                '1月',
                '2月',
                '3月',
                '4月',
                '5月',
                '6月',
                '7月',
                '8月',
                '9月',
                '10月',
                '11月',
                '12月',
            ],
        } });
};
export var Upload = __assign(__assign({}, common), { delete: '删除', retry: '重新上传', failed: '上传失败', limit: '文件添加个数已达上限', add: '添加文件', uploading: '文件上传中' });
export var Mention = {
    noContent: '无匹配结果，轻敲空格完成输入',
};
export var Transfer = {
    placeholder: '请输入搜索内容',
    item: '项',
    items: '项',
    emptyLabel: '暂无数据',
};
export var Form = {
    required: '必填',
};
export var NumberInput = {
    min: '最小值不能小于',
    max: '最大值不能大于',
};
